Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorMartin Poirier <theeth@yahoo.com>2008-04-08 17:40:05 +0400
committerMartin Poirier <theeth@yahoo.com>2008-04-08 17:40:05 +0400
commitca982d2a23b3de3c6e1f15b4aa3da49ab110763a (patch)
treebac4f984a5a7305c8e65cbffd709c855ad27e55f /source
parent589e641f97f81c130a94778e2a36e23eeac11dc5 (diff)
Proper fix for camera transform with snap.
Please email me or report a bug when such problem arise, it's simpler if done properly the first time.
Diffstat (limited to 'source')
-rw-r--r--source/blender/src/transform_constraints.c2
-rw-r--r--source/blender/src/transform_snap.c3
2 files changed, 3 insertions, 2 deletions
diff --git a/source/blender/src/transform_constraints.c b/source/blender/src/transform_constraints.c
index 5397fbcc4e1..b1720295774 100644
--- a/source/blender/src/transform_constraints.c
+++ b/source/blender/src/transform_constraints.c
@@ -245,7 +245,7 @@ static void applyAxisConstraintVec(TransInfo *t, TransData *td, float in[3], flo
Mat3MulVecfl(t->con.pmtx, out);
// With snap, a projection is alright, no need to correct for view alignment
- if (((t->tsnap.status & SNAP_ON) && (G.qual & LR_CTRLKEY)) == 0 ) {
+ if ((t->tsnap.status & SNAP_ON) == 0) {
if (getConstraintSpaceDimension(t) == 2) {
if (out[0] != 0.0f || out[1] != 0.0f || out[2] != 0.0f) {
planeProjection(t, in, out);
diff --git a/source/blender/src/transform_snap.c b/source/blender/src/transform_snap.c
index 23bfaf048df..30c65fd11f5 100644
--- a/source/blender/src/transform_snap.c
+++ b/source/blender/src/transform_snap.c
@@ -231,7 +231,8 @@ void initSnapping(TransInfo *t)
{
resetSnapping(t);
- if (t->spacetype == SPACE_VIEW3D || t->spacetype == SPACE_IMAGE) { // Only 3D view or UV
+ if ((t->spacetype == SPACE_VIEW3D || t->spacetype == SPACE_IMAGE) && // Only 3D view or UV
+ (t->flag & T_CAMERA) == 0) { // Not with camera selected
setSnappingCallback(t);
/* Edit mode */